#	Script for Glutamyl tRNA Synthetase
#	by Loren Williams

#	from 
#	TITLE     CRYSTAL STRUCTURE OF THERMUS THERMOPHILUS GLUTAMYL-TRNA               
#	TITLE    2 SYNTHETASE COMPLEXED WITH TRNA(GLU) AND GLUTAMOL-AMP.                
#	JRNL        AUTH   S.SEKINE,O.NUREKI,D.Y.DUBOIS,S.BERNIER,R.CHENEVERT,          
#	JRNL        AUTH 2 J.LAPOINTE,D.G.VASSYLYEV,S.YOKOYAMA                          
#	JRNL        TITL   ATP BINDING BY GLUTAMYL-TRNA SYNTHETASE IS                   
#	JRNL        TITL 2 SWITCHED TO THE PRODUCTIVE MODE BY TRNA BINDING              
#	JRNL        REF    EMBO J.                       V.  22   676 2003              

## Header: General Commands ##

# delete all objects and reset pymol
reinitialize
# set the background color to white
bg_color white
# make the background transparent for ray trace 
set ray_opaque_background, 0
# set the ray trace mode
# normal color
set ray_trace_mode, 0
# normal color + black outline
#set ray_trace_mode,  1
# black outline only
#set ray_trace_mode,  2
# turn off shadows during ray trace
set ray_shadows, 0
# set the mouse mode for laptop.
config_mouse one_button
# get rid of double bonds and skinny bonds to H
set stick_h_scale, 1
set valence, 0
# high quality surfaces
set surface_quality, 3

## End of Header: General Commands ##
#----------------------------------------

load files/1n78_GLUTAMYL.pdb, 1n78
remove chain B+D and 1n78
remove resn hoh

#				Glu Synthetase

create synthase_glu_ctoon, 1n78 and Chain A
create synthase_glu_stick, 1n78 and Chain A
hide everything, synthase_glu_*
show cartoon, synthase_glu_ctoon
show stick, synthase_glu_stick 
color cyan, synthase_*
color wheat, name C* and (synthase_glu_stick)
color red, name O* and (synthase_glu_stick)
color blue, name N* and (synthase_glu_stick)
color yellow, name P* and (synthase_glu_stick)
create KISKR, synthase_glu_stick and resi 243-247
create HIGH, synthase_glu_stick and resi 15-18
color limon, name C* and (KISKR)
color limon, name C* and (HIGH)
show sphere, KISKR 
show sphere, HIGH 


#				Glutamic Acid tRNA

create trna_glu_ctoon, 1n78 and Chain C
create trna_glu_stick, 1n78 and Chain C
hide everything, trna_glu_*
show cartoon, trna_glu_ctoon
set cartoon_ring_mode=3, trna_glu_ctoon
show stick, trna_glu_stick 
color green, name C* and (trna_glu_stick)
color red, name O* and (trna_glu_stick)
color blue, name N* and (trna_glu_stick)
color yellow, name P* and (trna_glu_stick)

list_hb (trna_glu_stick), (synthase_glu_stick) , cutoff=3.4, angle = 80, hb_list_name = tRNA_syn_HB

#		CCA
create cca, trna_glu_stick and resi 574-576
create cca_interface, byres((synthase_glu_stick and not resn synthase_glu_stick ) within 5 of cca)
list_hb (cca), (cca_interface) , cutoff=3.4, angle = 80, hb_list_name = cca_syn_HB

#				Glu adenylate

create adenylate, 1n78 and resn GOM
hide everything, adenylate
show stick, adenylate
show sphere, adenylate
color wheat, name C* and (adenylate)
color red, name O* and (adenylate)
color blue, name N* and (adenylate)
color yellow, name P* and (adenylate)

#		CUC anticodon
create anticodon, trna_glu_stick and resi 534-536
create anticodon_interface, byres((synthase_glu_stick and not resn synthase_glu_stick ) within 5 of anticodon)



distance  HB_AC, (name O*,N* and anticodon and resi 536), (name N*,O* and anticodon_interface) and resi 358, 3.4

distance  HB_AC, (name O*,N* and anticodon and resi 535), (name N*,O* and anticodon_interface) and not resi 435, 3.4

distance  HB_AC, (name O*,N* and anticodon and resi 534), (name N*,O* and anticodon_interface), 3.7



color black, tRNA_syn_
color black, anticodon_syn_HB
color black, cca_syn_HB
delete 1n78

disable all
enable synthase_glu_ctoon
enable trna_glu_ctoon
enable anticodon
enable anticodon_interface
enable anticodon_syn_HB
enable cca
enable cca_syn_HB
enable cca_interface
enable adenylate
 
set_view (\
     0.941765487,   -0.278575182,   -0.188344702,\
     0.303437918,    0.945396721,    0.118947342,\
     0.144924164,   -0.169170290,    0.974872887,\
    -0.000072241,    0.000006840, -312.827239990,\
    30.220855713,   61.156768799,   61.746688843,\
   260.566589355,  365.077972412,  -20.000000000 )
### cut above here and paste into script ### 